@@ -15,10 +15,13 @@ class ChessImageGenerator:
     def create_gif(game_data):
         "Prepare the rows and columns for the graph"
         matplotlib.use('agg')
-             
+
         gamedata_mapwhite = game_data["white"]
         gamedata_mapblack = game_data["black"]
 
+        if game_data == None:
+            print("Doing nothing for this game")
+
         filename = game_data["filename"]
 
         gamemax_controlwhite = game_data["max_white_value"]
